/**
 * BLOCK: donatepress-block
 */

//  Import CSS.
import './editor.scss';
import './style.scss';

const { __ } = wp.i18n; // Import __() from wp.i18n
const { registerBlockType } = wp.blocks; // Import registerBlockType() from wp.blocks

const {
	SelectControl,
	PanelBody,
	TextControl 
} = wp.components;

const {
	InspectorControls,
	RichText,
	PlainText
} = wp.editor;

var shortcode_obj = { email: "yourpaypalemail@example.com", size: "large", amount: "15.00", currency: "USD", purpose: "Charity for Child Health Care", mode: "live" };
registerBlockType( 'cgb/block-donatepress-block', {
	title: __( 'Donatepress Block' ), // Block title.
	icon: {
		src:'shield',
		background: '#14D9A3',
		foreground: '#004085',
	}, // Block icon from Dashicons → https://developer.wordpress.org/resource/dashicons/.
	category: 'common', // Block category — Group blocks together based on common traits E.g. common, formatting, layout widgets, embed.
	keywords: [
		__( 'donatepress-block' ),
		__( 'donation' ),
		__( 'donatepress' ),
	],
	attributes: {
		id: {
			type: 'number',
			default: 1
		},
		shortcode_content: {
			type: "string",
			source: "text",
			default: "[donatepress_payment_block email='" + shortcode_obj.email + "' amount='" + shortcode_obj.amount + "' currency='" + shortcode_obj.currency + "' size='" + shortcode_obj.size + "' purpose='" + shortcode_obj.purpose + "' mode='" + shortcode_obj.mode + "']"
		},
		selectnamecontrol: {
			type: 'string',
			default: ''
		},
		donatepress_Payment_email: {
			type: 'string',
			default: ''
		},
		donatepress_Payment_amount: {
			type: 'string',
			default: ''
		},
		donatepress_Payment_currency: {
			type: 'string',
			default: ''
		},
		donatepress_Payment_size: {
			type: 'string',
			default: ''
		},
		donatepress_Payment_purpsoe: {
			type: 'string',
			default: ''
		},
		donatepress_Payment_type: {
			type: 'string',
			default: ''
		},
		payment_method_type: {
			type: 'string',
			default: ''
		}
	},

	/**
	 * The edit function describes the structure of your block in the context of the editor.
	 * This represents what the editor will render when the block is used.
	 *
	 * The "edit" property must be a valid function.
	 *
	 * @link https://wordpress.org/gutenberg/handbook/block-api/block-edit-save/
	 *
	 * @param {Object} props Props.
	 * @returns {Mixed} JSX Component.
	 */



	 edit: function edit (props) {
		// Creates a <p class='wp-block-cgb-block-donatepress-block'></p>.
		const payment_method = [
			 { label: 'Paypal', value: 'paypal' }
		];

		const all_types = [
			{ label: 'Live', value: 'live' }, 
			{ label: 'Sandbox', value: 'sandbox' }
		];

		const select_template = [
			{ label: __('Select Template'), value: '' },
			{ label: __('Template 1'), value: 'temp1' },
			{ label: __('Template 2'), value: 'temp2' },
			{ label: __('Template 3'), value: 'temp3' }
		]

		const select_currency = [
					{ label: __('Select Currency'), value: '' }, 
					{ label: __('Australian Dollars (A $)'), value: 'AUD' },
			 		{ label: __('Brazilian Real'), value: 'BRL' },
			  		{ label: __('Canadian Dollars (C $)'), value: 'CAD' },
			   		{ label: __('Czech Koruna'), value: 'CZK' },
			    	{ label: __('Danish Krone'), value: 'DKK' },
				 	{ label: __('Euros (€)'), value: 'EUR' }, 
				 	{ label: __('Hong Kong Dollar ($)'), value: 'HKD' }, 
				 	{ label: __('Hungarian Forint'), value: 'HUF' },
				  	{ label: __('Israeli New Shekel'), value: 'ILS' },
				   	{ label: __('Yen (¥)'), value: 'JPY' }, 
				   	{ label: __('Malaysian Ringgit'), value: 'MYR' },
				    { label: __('Mexican Peso'), value: 'MXN' },
					{ label: __('Norwegian Krone'), value: 'NOK' },
					{ label: __('New Zealand Dollar ($)'), value: 'NZD' },
					{ label: __('Philippine Peso'), value: 'PHP' }, 
					{ label: __('Polish Zloty'), value: 'PLN' },
					{ label: __('Pounds Sterling (£)'), value: 'GBP' },
					{ label: __('Russian Ruble'), value: 'RUB' },
					{ label: __('Singapore Dollar ($)'), value: 'SGD' },
					{ label: __('Swedish Krona'), value: 'SEK' },
					{ label: __('Swiss Franc'), value: 'CHF' },
					{ label: __('Taiwan New Dollar'), value: 'TWD' }, 
					{ label: __('Thai Baht'), value: 'THB' },
					{ label: __('Turkish Lira'), value: 'TRY' }, 
					{ label: __('US Dollars'), value: 'USD' }
				]
		

				var attributes    = props.attributes,
                className         = attributes.className,
                shortcode_content = attributes.shortcode_content,
                Onchangename      = attributes.Onchangename,
                selectnamecontrol = attributes.selectnamecontrol,
                donatepress_Payment_email      = attributes.donatepress_Payment_email,
                donatepress_Payment_amount     = attributes.donatepress_Payment_amount,
                donatepress_Payment_currency   = attributes.donatepress_Payment_currency,
                donatepress_Payment_size       = attributes.donatepress_Payment_size,
                donatepress_Payment_purpsoe    = attributes.donatepress_Payment_purpsoe,
                donatepress_Payment_type       = attributes.donatepress_Payment_type,
                payment_method_type  = attributes.payment_method_type,
                setAttributes     = props.setAttributes;

				var OnchangePaypalType = function OnchangePaypalType(newContent) {
					var userEmail    = donatepress_Payment_email ? donatepress_Payment_email : shortcode_obj.email;
					var userAmount   = donatepress_Payment_amount ? donatepress_Payment_amount : shortcode_obj.amount;
					var userCurrency = donatepress_Payment_currency ? donatepress_Payment_currency : shortcode_obj.currency;
					var userPurpsoe  = donatepress_Payment_purpsoe ? donatepress_Payment_purpsoe : shortcode_obj.purpose;
					var userSize     = donatepress_Payment_size ? donatepress_Payment_size : shortcode_obj.size;
	
					var type_new_content = "[donatepress_payment_block email='" +
					                       userEmail + "' amount='" + userAmount + 
										   "' currency='" + userCurrency + "' size='" + 
										   userSize + "' purpose='" + userPurpsoe + "' mode='" + 
										   newContent + "']";
										   
					shortcode_obj.mode = newContent;
					setAttributes({ shortcode_content: type_new_content });
					setAttributes({ donatepress_Payment_type: newContent });
				};

				var onChangePaypalEmail = function onChangePaypalEmail(newContent) {

					var userAmount    = donatepress_Payment_amount ? donatepress_Payment_amount : shortcode_obj.amount;
					var userCurrency  = donatepress_Payment_currency ? donatepress_Payment_currency : shortcode_obj.currency;
					var userSize      = donatepress_Payment_size ? donatepress_Payment_size : shortcode_obj.size;
					var userPurpsoe   = donatepress_Payment_purpsoe ? donatepress_Payment_purpsoe : shortcode_obj.purpose;
					var userMode      = donatepress_Payment_type ? donatepress_Payment_type : shortcode_obj.mode;
	
					var email_new_content = "[donatepress_payment_block email='" + newContent + 
											"' amount='" + userAmount + "' currency='" + 
											userCurrency + "' size='" + userSize + 
											"'  purpose='" + userPurpsoe + "' mode='" +
											 userMode + "']";
					shortcode_obj.email = newContent;
					setAttributes({ shortcode_content: email_new_content });
					setAttributes({ donatepress_Payment_email: newContent });
				};

				var onChangePaypalAmount = function onChangePaypalAmount(newContent) {
					var userEmail      = donatepress_Payment_email ? donatepress_Payment_email : shortcode_obj.email;
					var userCurrency   = donatepress_Payment_currency ? donatepress_Payment_currency : shortcode_obj.currency;
					var userSize       = donatepress_Payment_size ? donatepress_Payment_size : shortcode_obj.size;
					var userPurpsoe    = donatepress_Payment_purpsoe ? donatepress_Payment_purpsoe : shortcode_obj.purpose;
					var userMode       = donatepress_Payment_type ? donatepress_Payment_type : shortcode_obj.mode;
	
					var amount_new_content = "[donatepress_payment_block email='" + userEmail +
										 "' amount='" + newContent + "' currency='" + 
										 userCurrency + "' size='" + userSize + 
										 " purpose='" + userPurpsoe + "' mode='" + 
										 userMode + "']";
					shortcode_obj.amount = newContent;
					setAttributes({ shortcode_content: amount_new_content });
					setAttributes({ donatepress_Payment_amount: newContent });
				};

				var onChangeCurrency = function onChangeCurrency(newContent) {
					var userEmail = donatepress_Payment_email ? donatepress_Payment_email : shortcode_obj.email;
					var userAmount = donatepress_Payment_amount ? donatepress_Payment_amount : shortcode_obj.amount;
					var userSize = donatepress_Payment_size ? donatepress_Payment_size : shortcode_obj.size;
					var userPurpsoe = donatepress_Payment_purpsoe ? donatepress_Payment_purpsoe : shortcode_obj.purpose;
					var userMode = donatepress_Payment_type ? donatepress_Payment_type : shortcode_obj.mode;
	
					var currency_new_content = "[donatepress_payment_block email='" + 
											userEmail + "' amount='" + userAmount + 
											"' currency='" + newContent +
					 						"' size='" + userSize + "' purpose='" +
					  						userPurpsoe + "' mode='" + userMode + "']";
					shortcode_obj.currency = newContent;
					setAttributes({ shortcode_content: currency_new_content });
					setAttributes({ donatepress_Payment_currency: newContent });
				};

				var onChangeButtonSize = function onChangeButtonSize(newContent) {
					var userEmail = donatepress_Payment_email ? donatepress_Payment_email : shortcode_obj.email;
					var userAmount = donatepress_Payment_amount ? donatepress_Payment_amount : shortcode_obj.amount;
					var userCurrency = donatepress_Payment_currency ? donatepress_Payment_currency : shortcode_obj.currency;
					var userPurpsoe = donatepress_Payment_purpsoe ? donatepress_Payment_purpsoe : shortcode_obj.purpose;
					var userMode = donatepress_Payment_type ? donatepress_Payment_type : shortcode_obj.mode;
	
					var button_new_content = "[donatepress_payment_block email='" +
											 userEmail + "' amount='" + userAmount + 
											 " currency='" + userCurrency + "' size='" + 
											 newContent + "' purpose='" + userPurpsoe + 
											 "' mode='" + userMode + "']";
					shortcode_obj.size = newContent;
					setAttributes({ shortcode_content: button_new_content });
					setAttributes({ donatepress_Payment_size: newContent });
				};

				var onChangePurpose = function onChangePurpose(newContent) {
					var userEmail = donatepress_Payment_email ? donatepress_Payment_email : shortcode_obj.email;
					var userAmount = donatepress_Payment_amount ? donatepress_Payment_amount : shortcode_obj.amount;
					var userCurrency = donatepress_Payment_currency ? donatepress_Payment_currency : shortcode_obj.currency;
					var userSize = donatepress_Payment_size ? donatepress_Payment_size : shortcode_obj.size;
					var userMode = donatepress_Payment_type ? donatepress_Payment_type : shortcode_obj.mode;
	
					var purpose_new_content = "[donatepress_payment_block email='" +
										 userEmail + "' amount='" + userAmount + 
										 "' currency='" + userCurrency + "' size='" +
										  userSize + "' purpose='" + newContent +
										   "' mode='" + userMode + "']";
					shortcode_obj.purpose = newContent;
					setAttributes({ shortcode_content: purpose_new_content });
					setAttributes({ donatepress_Payment_purpsoe: newContent });
				};

				function onChangeShortcodeTitle(newContent) {
					setAttributes({ shortcode_content: newContent });
				}

		return ([
			<InspectorControls>
				  <div className="donate-panel-op">
						<PanelBody>
							<div className='payment_select'>
							<SelectControl
								label = 'Payment Method'
								options = {payment_method}
								//onChange = {OnchangePaypalType }
								value = {payment_method_type}
							/>
							</div>
							<SelectControl
								label = 'Paypal Mode'
								options = {all_types}
								onChange = {OnchangePaypalType }
								value = {donatepress_Payment_type}
							/>
							<TextControl
								label="Email"
								value={ donatepress_Payment_email }
								onChange={ onChangePaypalEmail }
							/>
							<TextControl
								label="Amount"
								type="number"
								value={ donatepress_Payment_amount }
								onChange={ onChangePaypalAmount }
							/>
							<SelectControl
								label = 'Select Currency'
								options = {select_currency}
								onChange = {onChangeCurrency }
								value = {donatepress_Payment_currency}
							/>
							<SelectControl
								label = 'Select Template'
								options = {select_template}
								onChange = {onChangeButtonSize }
								value = {donatepress_Payment_size}
							/>
							<TextControl
								label="Purpose"
								value={ donatepress_Payment_purpsoe }
								onChange={ onChangePurpose }
							/>
						</PanelBody>
					</div>
    				
    			</InspectorControls>,

			<PlainText
				className='input-control'
				value={ shortcode_content }
				placeholder= "Write shortcode here\u2026"
				onChange={ onChangeShortcodeTitle }
			/>
		]);
	},

	/**
	 * The save function defines the way in which the different attributes should be combined
	 * into the final markup, which is then serialized by Gutenberg into post_content.
	 *
	 * The "save" property must be specified and must be a valid function.
	 */
	save: function save(props)  {
		var attributes = props.attributes;
		var shortcode_content = attributes.shortcode_content;
		return (
			<div className={ props.className }>
				{shortcode_content}
			</div>
		);
	},
} );
